@@ -1,4 +1,4 @@
-/* Copyright (C) 2016-2021 Greenbone Networks GmbH
+/* Copyright (C) 2016-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -19,8 +19,25 @@ import React from 'react';
 
 import ReactDOM from 'react-dom';
 
+import * as Sentry from '@sentry/react';
+
+import GSA_VERSION from 'version';
+
+import {isDefined} from 'gmp/utils/identity';
+
 import App from './web/app.js';
 
+const config = isDefined(global.config) ? global.config : {};
+const {sentryDSN, sentryEnvironment} = config;
+
+Sentry.init({
+  attachStacktrace: true,
+  dsn: sentryDSN,
+  environment: sentryEnvironment,
+  enabled: isDefined(sentryDSN),
+  release: GSA_VERSION,
+});
+
 ReactDOM.render(<App />, document.getElementById('app'));
 
 // vim: set ts=2 sw=2 tw=80:
