@@ -1,4 +1,4 @@
-/* Copyright (C) 2019-2021 Greenbone Networks GmbH
+/* Copyright (C) 2019-2022 Greenbone Networks GmbH
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -42,7 +42,7 @@ const ProductImage = props => {
       src={
         isDefined(settings) && isDefined(settings.vendorLabel)
           ? settings.vendorLabel
-          : 'login-label.png'
+          : 'login-label.svg'
       }
     />
   );
